@@ -10,6 +10,8 @@ use Carp;
 use XML::LibXML;
 use XML::LibXML::XPathContext;
 
+our $VERSION = '0.040';
+
 with 'Catmandu::Importer';
 
 # required.
@@ -32,6 +34,8 @@ has _currentRecordSet => (is => 'ro');
 has _n => (is => 'ro', default => sub { 0 });
 has _start => (is => 'ro', default => sub { 1 });
 has _max_results => (is => 'ro', default => sub { 10 });
+has _meta_get => (is => 'ro');
+has _meta_destr => (is => 'ro', default => sub { 1 });
 
 # Internal Methods. ------------------------------------------------------------
 
@@ -83,11 +87,15 @@ sub _hashify {
   my $parser = XML::LibXML->new();
   my $doc    = $parser->parse_string($in);
   my $root   = $doc->documentElement;
+  my @namespaces = $root->getNamespaces;
+
   my $xc     = XML::LibXML::XPathContext->new( $root );
   $xc->registerNs("srw","http://www.loc.gov/zing/srw/");
   $xc->registerNs("d","http://www.loc.gov/zing/srw/diagnostic/");
   
   my $diagnostics = {};
+  my $meta;
+  my $records     = {};
 
   if ($xc->exists('/srw:searchRetrieveResponse/srw:diagnostics')) {
     $diagnostics->{diagnostic} = [];
@@ -97,29 +105,59 @@ sub _hashify {
        my $message = $xc->findvalue('./d:message',$_);
        my $details = $xc->findvalue('./d:details',$_);
 
-       push @{$diagnostics->{diagnostic}} , 
+       push @{$diagnostics->{diagnostic}} ,
                 { uri => $uri , message => $message , details => $details } ;
     }
+  } elsif ($self->_meta_get) {
+      for ($xc->findnodes('/srw:searchRetrieveResponse')) {
+        for ($xc->findnodes('./*', $_)) {
+          my $tagName = $_->tagName;
+          next if $tagName eq 'records';
+          if($tagName eq 'echoedSearchRetrieveRequest' or $tagName eq 'extraResponseData') {
+            my $key = $tagName;
+            $meta->{$key} = {};
+            for ($xc->findnodes("/srw:searchRetrieveResponse/srw:$key")) {
+              for ($xc->findnodes('./*', $_)) {
+                if(defined $_->prefix) {
+                    $xc->registerNs($_->prefix,$_->namespaceURI());
+                }
+                my $tagName = $_->tagName;
+                $meta->{$key}->{$tagName} = $xc->findvalue(".",$_);
+              }
+            }
+          } else {
+            $meta->{$tagName} = $xc->findvalue(".",$_);
+        }
+      }
+    }
   }
-
-  my $records = { };
-
+  
   if ($xc->exists('/srw:searchRetrieveResponse/srw:records')) {
       $records->{record} = [];
 
       for ($xc->findnodes('/srw:searchRetrieveResponse/srw:records/srw:record')) {
         my $recordSchema   = $xc->findvalue('./srw:recordSchema',$_);
         my $recordPacking  = $xc->findvalue('./srw:recordPacking',$_);
-        my $recordData     = '' . $xc->find('./srw:recordData/*',$_)->pop();
+        my $recordData     = $xc->find('./srw:recordData/*',$_)->pop();
         my $recordPosition = $xc->findvalue('./srw:recordPosition',$_);
-       
-        push @{$records->{record}} , 
-              { recordSchema => $recordSchema , recordPacking => $recordPacking , 
+
+        # Copy all the root level namespaces to the record Element.
+        for (@namespaces) {
+            my $ns_prefix = $_->declaredPrefix;
+            my $ns_uri    = $_->declaredURI;
+            # Skip the SRW namespaces
+            unless ($ns_uri =~ m{http://www.loc.gov/zing/srw/}) {
+                $recordData->setNamespace($ns_uri,$ns_prefix,0);
+            }
+        }
+
+        push @{$records->{record}} ,
+              { recordSchema => $recordSchema , recordPacking => $recordPacking ,
                 recordData => $recordData , recordPosition => $recordPosition };
       }
   }
 
-  return { diagnostics => $diagnostics , records => $records };
+  return { diagnostics => $diagnostics , records => $records, meta => $meta };
 }
 
 sub url {
@@ -157,10 +195,11 @@ sub _nextRecordSet {
   }
 
   # get to the point.
+  my $meta = $hash->{'meta'};
   my $set = $hash->{'records'}->{'record'};
 
   # return a reference to a array.
-  return \@{$set};
+  return { record => \@{$set}, meta => $meta };
 }
 
 # Internal: gets the next record from our current resultset.
@@ -174,29 +213,53 @@ sub _nextRecord {
 
   # check for a exhaused recordset.
   if ($self->_n >= $self->_max_results) {
-	  $self->{_start} += $self->_max_results;
-	  $self->{_n} = 0;
+    $self->{_start} += $self->_max_results;
+    $self->{_n} = 0;
     $self->{_currentRecordSet} = $self->_nextRecordSet;
   }
 
-  # return the next record.
-  my $record = $self->_currentRecordSet->[$self->{_n}++];
+  # return the next record or metadata.
+  my $record = $self->{_currentRecordSet}->{record}->[$self->{_n}++];
 
   if (defined $record) {
-      if (is_code_ref($self->parser)) {
-          $record = $self->parser->($record);
-      } else {
-          $record = $self->parser->parse($record);
-      }
+    if (is_code_ref($self->parser)) {
+        $record = $self->parser->($record);
+    } else {
+        $record = $self->parser->parse($record);
+    }
   }
   return $record;
 }
 
+# Internal: gets searchRetrieveResponse metadata of the request
+#
+# Returns a hash representation of the metadata.
+sub _meta {
+  my ($self) = @_;
+
+  my $meta;
+  if($self->_meta_destr) {
+    $self->{_currentRecordSet} = $self->_nextRecordSet;
+    $meta = $self->{_currentRecordSet}->{meta};
+    $meta = $self->parser->parse($meta);
+    $self->{_meta_destr} = 0;
+  }
+
+  return $meta;
+}
+
 # Public Methods. --------------------------------------------------------------
 
 sub generator {
   my ($self) = @_;
 
+  if (ref $self->parser eq 'Catmandu::Importer::SRU::Parser::meta') {
+    $self->{_meta_get} = 1;
+    return sub {
+      $self->_meta;
+    };
+  }
+
   return sub {
     $self->_nextRecord;
   };
@@ -237,7 +300,7 @@ sub generator {
   );
 
   # Using a homemade parser
-  
+
   my $importer = Catmandu::Importer::SRU->new(
     base => 'http://www.unicat.be/sru',
     query => '(isbn=0855275103 or isbn=3110035170 or isbn=9010017362 or isbn=9014026188)',
@@ -302,7 +365,7 @@ instance C<marcxml> will create a C<Catmandu::Importer::SRU::Parser::marcxml>.
 =item
 
 Function reference that gets passed the unparsed record.
- 
+
 =back
 
 =back
