@@ -1,6 +1,6 @@
 =head1 NAME
 
-  Catmandu::Importer::SRU::Parser::marcxml - Package transforms SRU responses into Catmandu MARC 
+  Catmandu::Importer::SRU::Parser::marcxml - Package transforms SRU responses into Catmandu MARC
 
 =head1 SYNOPSIS
 
@@ -27,20 +27,18 @@ package Catmandu::Importer::SRU::Parser::marcxml;
 use Moo;
 use XML::LibXML;
 
+our $VERSION = '0.040';
+
 sub parse {
 	my ($self,$record) = @_;
 
-  my $xml = $record->{recordData};
+  my $marc   = $record->{recordData};
 
-	my $parser = XML::LibXML->new();
-  my $doc    = $parser->parse_string($xml);
-  my $root   = $doc->documentElement;
-  
   my @out;
   my $id = undef;
 
-  for my $field ($root->getChildrenByLocalName('*')) {
-      my $name = $field->localname;
+  for my $field ($marc->getChildrenByLocalName('*')) {
+      my $name  = $field->localname;
       my $value = $field->textContent // '';
       if ($name eq 'leader') {
            push @out, [ 'LDR', ' ', ' ', '_', $value ];
