@@ -20,7 +20,7 @@ Transforms each SRU record into a Perl hash containing the following fields:
   * recordSchema - the SRU record schema (see: http://www.loc.gov/standards/sru/recordSchemas/index.html)
   * recordPacking - the SRU format (can be 'string' or 'xml')
   * recordPosition - the result number
-  * recordData - the unparsed record payload 
+  * recordData - the unparsed record payload
 
 =head1 AUTHOR
 
@@ -31,8 +31,15 @@ package Catmandu::Importer::SRU::Parser::raw;
 
 use Moo;
 
+our $VERSION = '0.040';
+
 sub parse {
-	return $_[1];
+    my ($self,$record) = @_;
+
+    my $xml = $record->{recordData}->toString;
+    $record->{recordData} = $xml;
+
+	return $record;
 }
 
-1;
\ No newline at end of file
+1;
