@@ -25,13 +25,15 @@ use strict;
 use XML::LibXML::Simple ();
 use Moo;
 
+our $VERSION = '0.040';
+
 has xmlsimple => ( is => 'ro', default => sub { XML::LibXML::Simple->new } );
 
 sub parse {
 	my ($self, $record) = @_;
 
     $record->{recordData} = $self->xmlsimple->XMLin(
-        $record->{recordData} , KeepRoot => 1, NsStrip => 1
+        $record->{recordData}->toString , KeepRoot => 1, NsStrip => 1
     );
 
     $record;
