@@ -1,22 +1,29 @@
 package Catmandu::SRU;
 
+our $VERSION = '0.040';
+
 =head1 NAME
 
 Catmandu::SRU - Catmandu module for working with SRU data
 
-=cut
+=begin markdown
 
-our $VERSION = '0.039';
+# STATUS
+[![Build Status](https://travis-ci.org/LibreCat/Catmandu-SRU.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-SRU)
+[![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-SRU/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-SRU)
+[![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-SRU.png)](http://cpants.cpanauthors.org/dist/Catmandu-SRU)
+
+=end markdown
 
 =head1 SYNOPSIS
 
  # On the command line
- $ catmandu convert SRU  --base http://www.unicat.be/sru --query data
+ $ catmandu convert SRU --base http://www.unicat.be/sru --query data
 
- $ catmandu convert SRU  --base http://www.unicat.be/sru --query data  --recordSchma marcxml
+ $ catmandu convert SRU --base http://www.unicat.be/sru --query data  --recordSchema marcxml
+
+ $ catmandu convert SRU --base http://www.unicat.be/sru --query data  --recordSchema marcxml --parser marcxml
 
- $ catmandu convert SRU  --base http://www.unicat.be/sru --query data  --recordSchma marcxml --parser marcxml
- 
  # create a config file: catmandu.yml
  $ cat catmandu.yml
  ---
@@ -24,7 +31,7 @@ our $VERSION = '0.039';
    unicat:
      package: SRU
      options:
-     	base: http://www.unicat.be/sru 
+     	base: http://www.unicat.be/sru
      	recordSchema: marcxml
      	parser: marcxml
 
@@ -45,7 +52,7 @@ our $VERSION = '0.039';
   );
 
   $exporter->commit;
- 
+
 =head1 MODULES
 
 =over 2
@@ -62,6 +69,10 @@ our $VERSION = '0.039';
 
 =item L<Catmandu::Importer::SRU::Parser::marcxml>
 
+=item L<Catmandu::Importer::SRU::Parser::meta>
+
+=item L<Catmandu::Importer::SRU::Parser::mods>
+
 =back
 
 =head1 SEE ALSO
@@ -82,9 +93,9 @@ Patrick Hochstenbach, C<< <patrick.hochstenbach at ugent.be> >>
 
 Nicolas Steenlant, C<< <nicolas.steenlant at ugent.be> >>
 
-Jakob Voss C<< jakob.voss at gbv.de >>
+Jakob Voss C<< <jakob.voss at gbv.de> >>
 
-Johann Rolschewski C<< rolschewski at gmail.com >>
+Johann Rolschewski C<< <jorol at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
